@@ -31,4 +31,6 @@ v1.0.6 v1.0.5
 * 新增[@x="x" and @y>10]条件筛选 (>,<,=,>=,<=) (and, or, |, &)
 * 新增*[a,b] 多项泛解析解析，同时可使用@条件
 * 删除原切片与索引同时使用的功能
+v1.0.7
+* 修复slice使用的bug
 '''
